==> lxqt-session_2.2.0.orig.tar.xz: lxqt-session-2.2.0/lxqt-leave/translations/lxqt-leave_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Què voleu que faci l&apos;ordinador?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Logout</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="79"/>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Shutdown</source>
        <translation>Apaga</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="71"/>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="76"/>
        <source>Lock screen</source>
        <translation>Bloqueja la pantalla</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="84"/>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Logout.</source>
        <translation>Tanca la sessió.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Lockscreen.</source>
        <translation>Bloqueja la pantalla.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Suspend.</source>
        <translation>Suspèn.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Hibernate.</source>
        <translation>Hiberna.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Shutdown.</source>
        <translation>Apaga.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reboot.</source>
        <translation>Reinicia.</translation>
    </message>
</context>
</TS>

==> lxqt-session_2.3.0.orig.tar.xz: lxqt-session-2.3.0/lxqt-leave/translations/lxqt-leave_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Què voleu que faci l&apos;ordinador?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Logout</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="79"/>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Shutdown</source>
        <translation>Apaga</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="71"/>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="76"/>
        <source>Lock screen</source>
        <translation>Bloqueja la pantalla</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="84"/>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Logout.</source>
        <translation>Tanca la sessió.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Lockscreen.</source>
        <translation>Bloqueja la pantalla.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Suspend.</source>
        <translation>Suspèn.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Hibernate.</source>
        <translation>Hiberna.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Shutdown.</source>
        <translation>Atura.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reboot.</source>
        <translation>Reinicia.</translation>
    </message>
</context>
</TS>
